.. nodoctest
.. autodoc_member_order: 'bysource'

Grid View Widget
================

.. automodule:: sage_combinat_widgets.grid_view_widget
   :members:
   :special-members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: compute_tooltip, get_model_id
